Installation
------------

Python module::

   pip install radstats

Source code::

   git clone https://github.com/rdt249/radstats
   cd radstats
   pip install -r requirements.txt


Documentation
-------------

https://radstats.readthedocs.io/en/latest/
